betty.serde.load module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.serde.load module

An API to load serializable data dumps.

class betty.serde.load.Loadable

  Bases: `ABC`

  Instances can load serializable data dumps into `self`.

  abstract load(dump: Dump) → None

    Load a serialized data dump into `self`.

    Raises:

      betty.assertion.error.AssertionFailed – Raised if the dump is invalid.